@@ -490,8 +490,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         )
 
     async def query(
-        self, given_client: edgedb.AsyncIOClient = None
-    ) -> T.List[NodeType]:
+        self, given_client: edgedb.AsyncIOClient = None, only_one: bool = False
+    ) -> T.Union[T.List[NodeType], NodeType]:
         query_str = self.full_query_str()
         with safe_span(
             op=f"edgedb.query.{self._model_name}", description=query_str[:200]
@@ -500,9 +500,12 @@ class Resolver(BaseModel, T.Generic[NodeType]):
                 client=given_client or self._node.db_client,
                 query_str=query_str,
                 variables=self._get_nested_query_variables(),
+                only_one=only_one,
             )
         with safe_span(op=f"parse.{self._model_name}", description=f"{len(raw_d)=}"):
-            return [self.parse_nested_obj(d) for d in raw_d]
+            if not only_one:
+                return [self.parse_nested_obj(d) for d in raw_d]
+            return self.parse_nested_obj(raw_d)
 
     def clear_top_level_filters_and_variables(self) -> None:
         if self._filter:
